Command

Struct Command 

pub struct Command {
    pub com: BString,
    pub data: BString,
}
A free form command to be sent to the server. This is used for changing flags, respawning, spectating players, and selecting upgrades.

Changing a flag

let cmd = Command {
    com: "flag".into(),
    // Set to desired flag code,
    // unknown will result in UN flag.
    // Here we will set to the UN flag.
    data: "XX".into()
};

// Serialize and send to server here...

Respawning as a plane

let cmd = Command {
    com: "respawn".into(),
    // Choose the plane type here,
    // each type is associated with
    // an integer. Here we will pick
    // predator.
    data: "1".into()
};

// Serialize and send to server here...

Selecting Upgrades

let cmd = Command {
    com: "upgrade".into(),
    // Choose upgrade type here.
    // Here speed should be 1.
    data: "1".into()
};

// Serialize and send to server here...

Going into spectate or spectating a different player

let cmd = Command {
    com: "spectate".into(),
    // This can either be a player id, or
    // one of -1, -2, or -3. -3 will force
    // the player to go into spectate,
    // -1 switches focus to the next player,
    // and -2 switches focus to the previous
    // player. Here we will force the player
    // to go into spectate.
    data: "-3".into()
};

// Serialize and send to server here...

Fields

com: BString

The command to send to the server. The official server recognizes the commands "spectate", "upgrade", "flag", and "respawn".

data: BString

The data associated with the command, value values epend on the given command.