Horizon

Struct Horizon 

pub struct Horizon {
    pub horizon_x: u16,
    pub horizon_y: u16,
}
Packet to tell the server to resize the horizon for the client.

In theory this should expand the visible range for the client, in practice the official server appears to ignore these packets.

Fields

horizon_x: u16horizon_y: u16