Struct airmash_protocol::client::Pong[][src]

pub struct Pong {
    pub num: u32,
}

Response packet to server Pings.

Fields

The ping number, should correspond to the num field within in the Ping packet sent by the server.