ClientPacket

Enum ClientPacket 

#[non_exhaustive]
pub enum ClientPacket {
Show 14 variants Login(Login), Backup(Backup), Horizon(Horizon), Ack, Pong(Pong), Key(Key), Command(Command), ScoreDetailed, Chat(Chat), TeamChat(TeamChat), Whisper(Whisper), Say(Say), VoteMute(VoteMute), LocalPing(LocalPing),
}
All possible client packets.

This contains all valid packets that the client can send to the server (in the current version of the airmash protocol).

Some packets don’t contain any data, these packets do not have an associated struct and as such are just empty variants within this enum.

The From trait has been implemented for all the structs that correspond to the variants of this enum. This means that instead of directly constructing an instance of ClientPacket, into() can be called instead.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Login(Login)



Backup(Backup)



Horizon(Horizon)



Ack



Pong(Pong)



Key(Key)



Command(Command)



ScoreDetailed



Chat(Chat)



TeamChat(TeamChat)



Whisper(Whisper)



Say(Say)



VoteMute(VoteMute)



LocalPing(LocalPing)