CommandReplyType

Enum CommandReplyType 

#[non_exhaustive]
pub enum CommandReplyType { ShowInConsole, ShowInPopup, Unknown(u8), }
Specifies whether the debug reply to a command should open a popup or be displayed in the chat window.

The original client will consider any command reply that isn’t ShowInConsole to be ShowInPopup however other clients may handle things differently.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ShowInConsole

Add a new message within the chat window.



ShowInPopup

Show a popup with the message.

Note that the original client will fail to show any message that is not valid JSON if shown in a popup.



Unknown(u8)