ErrorType

Enum ErrorType 

#[non_exhaustive]
pub enum ErrorType {
Show 18 variants PacketFloodingDisconnect, PacketFloodingBan, Banned, ForceClientReload, IdleRequiredBeforeRespawn, AfkTimeout, Kicked, InvalidLogin, IncorrectProtocol, AccountBanned, AccountAlreadyLoggedIn, NoRespawnInBTR, IdleRequiredBeforeSpectate, NotEnoughUpgrades, ChatThrottled, FlagChangeThrottled, UnknownCommand, Unknown(u8),
}
All error codes that can be sent to the client.

These are all server errors that the vanilla AIRMASH client (and the current STARMASH client) understands. Ab-server has some additional custom error types for its sync protocols but this crate doesn’t handle those packet types at the moment.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PacketFloodingDisconnect



PacketFloodingBan



Banned



ForceClientReload

This error doesn’t actually show an error on the client side but instead forces the client to reload the page.



IdleRequiredBeforeRespawn



AfkTimeout



Kicked



InvalidLogin



IncorrectProtocol



AccountBanned



AccountAlreadyLoggedIn



NoRespawnInBTR



IdleRequiredBeforeSpectate



NotEnoughUpgrades



ChatThrottled



FlagChangeThrottled



UnknownCommand



Unknown(u8)

Implementations

Source

impl ErrorType

pub const DisconnectedForPacketFlooding: Self = Self::PacketFloodingDisconnect

👎Deprecated since 0.6.0: use ErrorType::PacketFloodingDisconnect instead
pub const BannedForPacketFlooding: Self = Self::PacketFloodingBan

👎Deprecated since 0.6.0: use ErrorType::PacketFloodingBan instead
pub const IncorrectProtocolLevel: Self = Self::IncorrectProtocol

👎Deprecated since 0.6.0: use ErrorType::IncorrectProtocol instead