FlagCode

Enum FlagCode 

#[non_exhaustive]
pub enum FlagCode {
Show 126 variants SyrianArabRepublic, Thailand, Turkmenistan, Tunisia, Turkey, TrinidadandTobago, Taiwan, Tanzania, Ukraine, UnitedNations, UnitedStates, Uruguay, Uzbekistan, Venezuela, VietNam, PuertoRico, Portugal, Paraguay, Qatar, Rainbow, Romania, Serbia, RussianFederation, SaudiArabia, Sweden, Singapore, Slovenia, Slovakia, SanMarino, Macedonia, Macao, Malta, Mexico, Malaysia, Nigeria, Netherlands, Norway, Nepal, NewZealand, Oman, Panama, Peru, Japan, DPRK, SouthKorea, Kuwait, Kazakhstan, Lebanon, Liechtenstein, SriLanka, Lithuania, Luxembourg, Latvia, Honduras, Croatia, Hungary, Indonesia, Ireland, Israel, IsleofMan, ImperialJapan, India, Iraq, Germany, Denmark, DominicanRepublic, Algeria, Ecuador, Estonia, Egypt, Spain, EuropeanUnion, Bahrain, Bolivia, Brazil, Bhutan, Belarus, Canada, Switzerland, Andorra, UnitedArabEmirates, Albania, Armenia, Chile, Antarctica, China, Argentina, Finland, Colombia, Austria, Iran, France, Communist, Australia, LibyanArabJamahiriya, Iceland, UnitedKingdom, Confederate, Azerbaijan, Morocco, Italy, Georgia, CostaRica, BosniaAndHerzegovina, Philippines, Monaco, Jamaica, Greece, Cuba, Bangladesh, Somalia, Pakistan, Moldova, Jordan, Guatemala, Cyprus, Belgium, SouthAfrica, ElSalvador, Poland, Montenegro, JollyRogers, HongKong, CzechRepublic, Bulgaria, Unknown(u16),
}
All player flags currently available within the game.

This enum can be determined from a flag code string using the FromStr or TryFrom implementations. Usually the server will parse invalid flag code strings into the UnitedNations variant, but this is left up to the user.

Restricted Flags

In the official server the following flags are restricted to players level 4 and above:

Changing flags in-game are restricted to those level 2 and above, although any (non-restricted) flag can be chosen when logging in.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SyrianArabRepublic



Thailand



Turkmenistan



Tunisia



Turkey



TrinidadandTobago



Taiwan



Tanzania



Ukraine



UnitedNations



UnitedStates



Uruguay



Uzbekistan



Venezuela



VietNam



PuertoRico



Portugal



Paraguay



Qatar



Rainbow



Romania



Serbia



RussianFederation



SaudiArabia



Sweden



Singapore



Slovenia



Slovakia



SanMarino



Macedonia



Macao



Malta



Mexico



Malaysia



Nigeria



Netherlands



Norway



Nepal



NewZealand



Oman



Panama



Peru



Japan



DPRK



SouthKorea



Kuwait



Kazakhstan



Lebanon



Liechtenstein



SriLanka



Lithuania



Luxembourg



Latvia



Honduras



Croatia



Hungary



Indonesia



Ireland



Israel



IsleofMan



ImperialJapan



India



Iraq



Germany



Denmark



DominicanRepublic



Algeria



Ecuador



Estonia



Egypt



Spain



EuropeanUnion



Bahrain



Bolivia



Brazil



Bhutan



Belarus



Canada



Switzerland



Andorra



UnitedArabEmirates



Albania



Armenia



Chile



Antarctica



China



Argentina



Finland



Colombia



Austria



Iran



France



Communist



Australia



LibyanArabJamahiriya



Iceland



UnitedKingdom



Confederate



Azerbaijan



Morocco



Italy



Georgia



CostaRica



BosniaAndHerzegovina



Philippines



Monaco



Jamaica



Greece



Cuba



Bangladesh



Somalia



Pakistan



Moldova



Jordan



Guatemala



Cyprus



Belgium



SouthAfrica



ElSalvador



Poland



Montenegro



JollyRogers



HongKong



CzechRepublic



Bulgaria



Unknown(u16)