#[non_exhaustive]pub enum FlagUpdateType {
Position,
Carrier,
Unknown(u8),
}Expand description
Flag update type
Used to indicate whether the flag is now being carried by a player or whether the update sets the position of the flag directly.
Used in:
- TODO
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.