Enum airmash_protocol::LeaveHorizonType [−][src]
pub enum LeaveHorizonType {
Player,
Mob,
}Indicates the type of entity that just went outside of the player's horizon.
TODO: Complete reverse engineering this. NOTE: The values here aren't in any way certain and should be verified before relying upon them.
Variants
PlayerMob