Enum airmash_protocol::PlayerLevelType [−][src]
pub enum PlayerLevelType {
Login,
LevelUp,
}Indicate whether a player levelled up, or has just logged in and their level is being communicated to the client.
Variants
LoginLevelUp