#[non_exhaustive]pub enum ServerPacket {
Show 48 variants
Login(Login),
Login2(Login2),
Backup,
Ping(Ping),
PingResult(PingResult),
Ack,
Error(Error),
CommandReply(CommandReply),
PlayerNew(PlayerNew),
PlayerLeave(PlayerLeave),
PlayerUpdate(PlayerUpdate),
PlayerFire(PlayerFire),
PlayerRespawn(PlayerRespawn),
PlayerFlag(PlayerFlag),
PlayerHit(PlayerHit),
PlayerKill(PlayerKill),
PlayerUpgrade(PlayerUpgrade),
PlayerType(PlayerType),
PlayerPowerup(PlayerPowerup),
PlayerLevel(PlayerLevel),
PlayerReteam(PlayerReteam),
GameFlag(GameFlag),
GameSpectate(GameSpectate),
GamePlayersAlive(GamePlayersAlive),
GameFirewall(GameFirewall),
EventRepel(EventRepel),
EventBoost(EventBoost),
EventBounce(EventBounce),
EventStealth(EventStealth),
EventLeaveHorizon(EventLeaveHorizon),
MobUpdate(MobUpdate),
MobUpdate2(MobUpdate2),
MobUpdateStationary(MobUpdateStationary),
MobDespawn(MobDespawn),
MobDespawnCoords(MobDespawnCoords),
ScoreUpdate(ScoreUpdate),
ScoreBoard(ScoreBoard),
ScoreDetailedFFA(ScoreDetailedFFA),
ScoreDetailedCTF(ScoreDetailedCTF),
ScoreDetailedBTR(ScoreDetailedBTR),
ChatTeam(ChatTeam),
ChatPublic(ChatPublic),
ChatSay(ChatSay),
ChatWhisper(ChatWhisper),
ChatVoteMutePassed(ChatVoteMutePassed),
ChatVoteMuted,
ServerMessage(ServerMessage),
ServerCustom(ServerCustom),
}Expand description
All possible server packets.
This is an enum of all possible packet message types. Some packets do not contain any data and thus do not have any data within their enum variants.
The From trait has been implemented for all the structs that
correspond to the variants of this enum. This means that instead of directly
constructing an instance of ServerPacket, into() can be called
instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Login(Login)
Login2(Login2)
Backup
Ping(Ping)
PingResult(PingResult)
Ack
Error(Error)
CommandReply(CommandReply)
PlayerNew(PlayerNew)
PlayerLeave(PlayerLeave)
PlayerUpdate(PlayerUpdate)
PlayerFire(PlayerFire)
PlayerRespawn(PlayerRespawn)
PlayerFlag(PlayerFlag)
PlayerHit(PlayerHit)
PlayerKill(PlayerKill)
PlayerUpgrade(PlayerUpgrade)
PlayerType(PlayerType)
PlayerPowerup(PlayerPowerup)
PlayerLevel(PlayerLevel)
PlayerReteam(PlayerReteam)
GameFlag(GameFlag)
GameSpectate(GameSpectate)
GamePlayersAlive(GamePlayersAlive)
GameFirewall(GameFirewall)
EventRepel(EventRepel)
EventBoost(EventBoost)
EventBounce(EventBounce)
EventStealth(EventStealth)
EventLeaveHorizon(EventLeaveHorizon)
MobUpdate(MobUpdate)
MobUpdate2(MobUpdate2)
MobUpdateStationary(MobUpdateStationary)
MobDespawn(MobDespawn)
MobDespawnCoords(MobDespawnCoords)
ScoreUpdate(ScoreUpdate)
ScoreBoard(ScoreBoard)
ScoreDetailedFFA(ScoreDetailedFFA)
ScoreDetailedCTF(ScoreDetailedCTF)
ScoreDetailedBTR(ScoreDetailedBTR)
ChatTeam(ChatTeam)
ChatPublic(ChatPublic)
ChatSay(ChatSay)
ChatWhisper(ChatWhisper)
ChatVoteMutePassed(ChatVoteMutePassed)
ChatVoteMuted
ServerMessage(ServerMessage)
ServerCustom(ServerCustom)