pub struct ChatWhisper {
pub from: Player,
pub to: Player,
pub text: BString,
}Expand description
A player has whispered.
This only occurs if the current player is either the whisperer or the one who originally sent the whisper message.
Fields
from: Playerto: Playertext: BStringTrait Implementations
Sourceimpl Clone for ChatWhisper
impl Clone for ChatWhisper
Sourcefn clone(&self) -> ChatWhisper
fn clone(&self) -> ChatWhisper
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatWhisper
impl Debug for ChatWhisper
Sourceimpl<'de> DeserializeV5<'de> for ChatWhisper
impl<'de> DeserializeV5<'de> for ChatWhisper
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl From<ChatWhisper> for ServerPacket
impl From<ChatWhisper> for ServerPacket
Sourcefn from(v: ChatWhisper) -> Self
fn from(v: ChatWhisper) -> Self
Converts to this type from the input type.
Sourceimpl SerializeV5 for ChatWhisper
impl SerializeV5 for ChatWhisper
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result