pub struct LoginPlayer {
pub id: Player,
pub status: PlayerStatus,
pub level: Level,
pub name: BString,
pub ty: PlaneType,
pub team: Team,
pub pos: Position,
pub rot: Rotation,
pub flag: FlagCode,
pub upgrades: Upgrades,
}Expand description
Initial data passed in for a player when the server starts.
This is an element of the players array within the Login packet.
Fields
id: Playerstatus: PlayerStatuslevel: Levelname: BStringty: PlaneTypeteam: Teampos: Positionrot: Rotationflag: FlagCodeupgrades: UpgradesTrait Implementations
Sourceimpl Clone for LoginPlayer
impl Clone for LoginPlayer
Sourcefn clone(&self) -> LoginPlayer
fn clone(&self) -> LoginPlayer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoginPlayer
impl Debug for LoginPlayer
Sourceimpl<'de> DeserializeV5<'de> for LoginPlayer
impl<'de> DeserializeV5<'de> for LoginPlayer
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl SerializeV5 for LoginPlayer
impl SerializeV5 for LoginPlayer
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result