pub struct MobUpdate {
pub clock: u32,
pub id: Mob,
pub ty: MobType,
pub pos: Position,
pub speed: Velocity,
pub accel: Accel,
pub max_speed: Speed,
}Expand description
Update for a mobile missile-type mob.
This is sent when a mob enters a player’s view radius or something changes about its state that needs to be communicated to the client.
Fields
clock: u32id: Mobty: MobTypepos: Positionspeed: Velocityaccel: Accelmax_speed: SpeedTrait Implementations
Sourceimpl<'de> DeserializeV5<'de> for MobUpdate
impl<'de> DeserializeV5<'de> for MobUpdate
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl From<MobUpdate> for ServerPacket
impl From<MobUpdate> for ServerPacket
Sourceimpl SerializeV5 for MobUpdate
impl SerializeV5 for MobUpdate
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result
impl Copy for MobUpdate