Struct airmash_protocol::server::Ping[][src]

pub struct Ping {
    pub clock: u32,
    pub num: u32,
}

A ping request by the server.

All clients must respond with a Pong with num set to the same value as this packet. If a client does not do this, the client will be disconnected by the server.

Fields