pub struct ServerCustom {
pub ty: ServerCustomType,
pub data: BString,
}Expand description
End of game packet for CTF and BTR.
CTF
In CTF, the data of this packet contains a JSON string with 3 fields.
w: The id of the winning team.b: The bounty given to each player of the winning team.t: The time (in seconds) that the banner should remain on screen before closing (unless closed by the player.)
BTR
In BTR, the data of this packet contains a JSON string with 5 fields.
p: The name of the winning player.f: The flag id of the winning player.b: The bounty given to the winning player.k: The number of kills that the winning player has.t: The time (in seconds) that the banner should remain on the screen before closing (unless closed by the player.)
Fields
ty: ServerCustomTypedata: BStringTrait Implementations
Sourceimpl Clone for ServerCustom
impl Clone for ServerCustom
Sourcefn clone(&self) -> ServerCustom
fn clone(&self) -> ServerCustom
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServerCustom
impl Debug for ServerCustom
Sourceimpl<'de> DeserializeV5<'de> for ServerCustom
impl<'de> DeserializeV5<'de> for ServerCustom
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl From<ServerCustom> for ServerPacket
impl From<ServerCustom> for ServerPacket
Sourcefn from(v: ServerCustom) -> Self
fn from(v: ServerCustom) -> Self
Converts to this type from the input type.
Sourceimpl SerializeV5 for ServerCustom
impl SerializeV5 for ServerCustom
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result