Struct airmash_protocol::Flag [−][src]
pub struct Flag(pub Team);
Methods
impl Flag[src]
impl FlagTrait Implementations
impl Copy for Flag[src]
impl Copy for Flagimpl Clone for Flag[src]
impl Clone for Flagfn clone(&self) -> Flag[src]
fn clone(&self) -> FlagReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for Flag[src]
impl Debug for Flagfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for Flag[src]
impl Eq for Flagimpl PartialEq for Flag[src]
impl PartialEq for Flagfn eq(&self, other: &Flag) -> bool[src]
fn eq(&self, other: &Flag) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Flag) -> bool[src]
fn ne(&self, other: &Flag) -> boolThis method tests for !=.
impl Hash for Flag[src]
impl Hash for Flagfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl From<Team> for Flag[src]
impl From<Team> for Flagimpl From<Flag> for Team[src]
impl From<Flag> for Teamimpl Component for Flag[src]
impl Component for Flagtype Storage = DenseVecStorage<Self>
Associated storage type for this component.