Struct airmash_protocol::Level [−][src]
pub struct Level(pub u8);
Type-safe Level identifier
Methods
impl Level[src]
impl LevelTrait Implementations
impl Copy for Level[src]
impl Copy for Levelimpl Clone for Level[src]
impl Clone for Levelfn clone(&self) -> Level[src]
fn clone(&self) -> LevelReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Eq for Level[src]
impl Eq for Levelimpl Hash for Level[src]
impl Hash for Levelfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for Level[src]
impl Debug for Levelfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Level[src]
impl PartialEq for Levelfn eq(&self, other: &Level) -> bool[src]
fn eq(&self, other: &Level) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Level) -> bool[src]
fn ne(&self, other: &Level) -> boolThis method tests for !=.
impl From<u8> for Level[src]
impl From<u8> for Levelimpl From<Level> for u8[src]
impl From<Level> for u8impl Add for Level[src]
impl Add for Leveltype Output = Level
The resulting type after applying the + operator.
fn add(self, rhs: Level) -> Level[src]
fn add(self, rhs: Level) -> LevelPerforms the + operation.
impl Sub for Level[src]
impl Sub for Leveltype Output = Level
The resulting type after applying the - operator.
fn sub(self, rhs: Level) -> Level[src]
fn sub(self, rhs: Level) -> LevelPerforms the - operation.
impl Component for Level[src]
impl Component for Leveltype Storage = DenseVecStorage<Self>
Associated storage type for this component.