Struct airmash_protocol::Mob [−][src]
pub struct Mob(pub u16);
A mob (missile, upgrade, or powerup) ID
Methods
impl Mob[src]
impl MobTrait Implementations
impl From<Entity> for Mob[src]
impl From<Entity> for Mobimpl Copy for Mob[src]
impl Copy for Mobimpl Clone for Mob[src]
impl Clone for Mobfn clone(&self) -> Mob[src]
fn clone(&self) -> MobReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for Mob[src]
impl Debug for Mobfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Default for Mob[src]
impl Default for Mobimpl Eq for Mob[src]
impl Eq for Mobimpl PartialEq for Mob[src]
impl PartialEq for Mobfn eq(&self, other: &Mob) -> bool[src]
fn eq(&self, other: &Mob) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Mob) -> bool[src]
fn ne(&self, other: &Mob) -> boolThis method tests for !=.
impl Hash for Mob[src]
impl Hash for Mobfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl From<u16> for Mob[src]
impl From<u16> for Mobimpl From<Mob> for u16[src]
impl From<Mob> for u16impl Component for Mob[src]
impl Component for Mobtype Storage = DenseVecStorage<Self>
Associated storage type for this component.