Struct airmash_protocol::Team [−][src]
pub struct Team(pub u16);
Type-safe team identifier
Methods
impl Team[src]
impl TeamTrait Implementations
impl From<Team> for Flag[src]
impl From<Team> for Flagimpl From<Flag> for Team[src]
impl From<Flag> for Teamimpl Copy for Team[src]
impl Copy for Teamimpl Clone for Team[src]
impl Clone for Teamfn clone(&self) -> Team[src]
fn clone(&self) -> TeamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Eq for Team[src]
impl Eq for Teamimpl Hash for Team[src]
impl Hash for Teamfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for Team[src]
impl Debug for Teamfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Team[src]
impl PartialEq for Teamfn eq(&self, other: &Team) -> bool[src]
fn eq(&self, other: &Team) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Team) -> bool[src]
fn ne(&self, other: &Team) -> boolThis method tests for !=.
impl From<u16> for Team[src]
impl From<u16> for Teamimpl From<Team> for u16[src]
impl From<Team> for u16impl Component for Team[src]
impl Component for Teamtype Storage = DenseVecStorage<Self>
Associated storage type for this component.