Struct airmash_protocol::Upgrades [−][src]
Upgrade info that a client needs to know about to calculate movement. This also includes the shielded state of the player.
Note that since a player should never have more than
5 upgrades on the official server, protocol-v5 can
only represent amounts of speed upgrades in the range
0 to 7.
Used in:
Login, specificallyLoginPlayerPlayerUpdatePlayerRespawnPlayerUpgrade
Fields
speed: u8
Note that only the first 3 bits of this are used in protocol-v5
shield: bool
inferno: bool