pub struct Backup {
pub token: BString,
}Expand description
Opening packet for opening a second server connection for the same client.
This packet is used to allow for multiple websocket connections to the
airmash server. To open a second connection, open a websocket connection to
the server, then send this packet as the first packet instead of sending
Login. The server will respond to client packets sent
through this channel, allowing for some reduction in head of line blocking.
Fields
token: BStringTrait Implementations
Sourceimpl<'de> DeserializeV5<'de> for Backup
impl<'de> DeserializeV5<'de> for Backup
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl From<Backup> for ClientPacket
impl From<Backup> for ClientPacket
Sourceimpl SerializeV5 for Backup
impl SerializeV5 for Backup
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result