pub struct Horizon {
pub horizon_x: u16,
pub horizon_y: u16,
}Expand description
Packet to tell the server to resize the horizon for the client.
In theory this should expand the visible range for the client, in practice the official server appears to ignore these packets.
Fields
horizon_x: u16horizon_y: u16Trait Implementations
Sourceimpl<'de> DeserializeV5<'de> for Horizon
impl<'de> DeserializeV5<'de> for Horizon
fn deserialize(de: &mut AirmashDeserializerV5<'de>) -> Result<Self>
Sourceimpl From<Horizon> for ClientPacket
impl From<Horizon> for ClientPacket
Sourceimpl SerializeV5 for Horizon
impl SerializeV5 for Horizon
fn serialize<'ser>(&self, ser: &mut AirmashSerializerV5<'ser>) -> Result
impl Copy for Horizon