Struct airmash_protocol::client::Horizon [−][src]
Packet to tell the server to resize the horizon for the client.
In theory this should expand the visible range for the client, in practice the official server appears to ignore these packets.
Fields
horizon_x: u16
horizon_y: u16