Enum airmash_protocol::CommandReplyType [−][src]
pub enum CommandReplyType {
ShowInConsole,
ShowInPopup,
}TODO: Reverse engineer
Variants
ShowInConsoleShowInPopupTechnically this should be any value other than 0, the from integer implementation for this enum deals with that.