Enum airmash_protocol::FlagUpdateType [−][src]
pub enum FlagUpdateType {
Position,
Carrier,
}Flag update type
Used to indicate whether the flag is now being carried by a player or whether the update sets the position of the flag directly.
Used in:
- TODO
Implementors Note: This had a TODO: rev-eng
comment on it but it doesn't seem to be missing
any values.
Variants
PositionCarrier