Struct airmash_protocol::server::EventLeaveHorizon [−][src]
pub struct EventLeaveHorizon {
pub ty: LeaveHorizonType,
pub id: u16,
}Event for when a player goes beyond the event horizon.
This indicates that the server will stop sending updates about this plane until it comes back within the event horizon.
Fields
ty: LeaveHorizonType
id: u16
This could be either a player or a mob TODO: Create Entity type