Struct airmash_protocol::server::LoginPlayer[][src]

pub struct LoginPlayer {
    pub id: Player,
    pub status: PlayerStatus,
    pub level: Level,
    pub name: String,
    pub ty: PlaneType,
    pub team: Team,
    pub pos: Position,
    pub rot: Rotation,
    pub flag: FlagCode,
    pub upgrades: Upgrades,
}

Initial data passed in for a player when the server starts.

This is an element of the players array within the Login packet.

Fields