Struct airmash_protocol::server::ServerCustom [−][src]
pub struct ServerCustom {
pub ty: ServerCustomType,
pub data: String,
}End of game packet for CTF and BTR.
CTF
In CTF, the data of this packet contains a JSON string with 3 fields.
w: The id of the winning team.b: The bounty given to each player of the winning team.t: The time (in seconds) that the banner should remain on screen before closing (unless closed by the player).
BTR
TODO
Fields
ty: ServerCustomType
data: String